@@ -18,6 +18,10 @@ import uuid
 from unify.orgadmin import OrgAdmin
 from unify.properties import Properties
 from unify.properties import ClusterSetting
+from unify.sources import Sources
+from unify.pipelines import Pipelines
+from unify.apimanager import ApiManager
+from unify.WaitingLibrary import Wait
 
 cluster_name = "qa"
 
@@ -36,4 +40,20 @@ test_org = org_admin.create_organization(
     org_name="zQA-{}".format(str(uuid.uuid4()))
 )
 
+sources = Sources(cluster=cluster_name, props=props)
+
+test_dataset = sources.static_file_upload(
+    name="table_{}".format(str(uuid.uuid4())[:12]),
+    org_id=test_org,
+    content="tests/data_test.csv"
+)
+
+pipelines = Pipelines(cluster=cluster_name, props=props)
+
+test_pipeline = pipelines.create_pipeline(name=str(uuid.uuid4()), org_id=test_org)
+
+api_manager = ApiManager(cluster=cluster_name, props=props)
+
+test_hierarchy = api_manager.create_hierarchy(name=str(uuid.uuid4()), org_id=test_org)
+
 print("--------Created organization {} for testing------", format(test_org))
