@@ -228,9 +228,9 @@ class ApiManager:
             sources = self.sources.get_sources(org_id=org_id)
 
             for source in sources:
-                if "fields" in source:
-                    if "schema" in source["fields"]:
-                        del source["fields"]["schema"]
+                if "schema" in source:
+                    del source["schema"]
+
             return sources
         except Exception as error:
             raise error
@@ -587,10 +587,8 @@ class ApiManager:
         result_data = []
 
         for source in sources:
-            if self.evergreen_enabled:
-                source_id_to_data[source["id"]["id"]] = source
-            else:
-                source_id_to_data[source["id"]["id"]] = source
+            source_id_to_data[source["id"]["id"]] = source
+
 
         pipeline_info = self.pipelines.get_pipeline(org_id=org_id, pipeline_id=pipeline_id)
 
@@ -605,12 +603,12 @@ class ApiManager:
 
                     if self.evergreen_enabled:
 
-                        source_data["schema"] = source_id_to_data[source_data["id"]]["fields"]["schema"]
+                        source_data["schema"] = source_id_to_data[source_data["id"]]["schema"]
 
                         source_data["name"] = source_id_to_data[source_data["id"]]["name"]
 
-                        if "ean.source_type" in source_id_to_data[source_data["id"]]["fields"]:
-                            source_data["type"] = source_id_to_data[source_data["id"]]["fields"]["ean.source_type"]
+                        if "ean_source_type" in source_id_to_data[source_data["id"]]["labels"]["raw"]:
+                            source_data["type"] = source_id_to_data[source_data["id"]]["labels"]["raw"]["ean_source_type"]
                         else:
                             source_data["type"] = "api_dataset"
 
@@ -675,12 +673,6 @@ class ApiManager:
                         )
                     )
 
-                    # self.create_map_attributes_without_download(
-                    #    component=component,
-                    #    org_id=org_id,
-                    #    pipeline_id=pipeline_id
-                    # )
-
                 if component["jsonClass"] == "JsonFunctionApply":
                     func_id = "{}.{}.{}".format(pipeline_id, component["id"], component["pipelineId"])
                     results["functions"][func_id] = json.loads(
