@@ -30,7 +30,7 @@ def build_header(auth_token=None, org_id=None, others=None):
     :type others: dict
     :return:
     """
-    header = dict()
+    header = {}
 
     if others is not None and isinstance(others, dict):
         header.update(others)
@@ -75,7 +75,7 @@ def save_flow_download(name, data):
     :type data: str
     :return:
     """
-    file_dir = "{}.csv".format(name)
+    file_dir = f"{name}.csv"
 
     fil = open(file_dir, "wb+")
 
@@ -102,7 +102,7 @@ def remove_special(out_file, data_array):
 
         csv_writer = csv.writer(csv_r, delimiter=',', quotechar='"', quoting=csv.QUOTE_ALL)
 
-        first=True
+        first = True
 
         for row_json in data_array:
 
@@ -114,9 +114,9 @@ def remove_special(out_file, data_array):
                 del row_json["metricsId"]
 
             if first:
-                first=False
+                first = False
                 csv_writer.writerow(row_json.keys())
 
-            csv_writer.writerow([valu for key,valu in row_json.items()])
+            csv_writer.writerow([valu for key, valu in row_json.items()])
 
     return server_name_value
