@@ -25,6 +25,7 @@ from unify.properties import Properties
 from unify.properties import ClusterSetting
 from unify.apirequestsmng import ApiRequestManager
 from unify.helpers.SingleOrg import single_org
+from unify.helpers.graph_ql.pipeline_gql import PipelineGrapql
 
 
 class Pipelines(ApiRequestManager):
@@ -99,6 +100,8 @@ class Pipelines(ApiRequestManager):
             self.distinct_values_url = self.props.get_remote(
                 self.cluster) + 'tags/org/{}/pipelines/{}/flows/{}/distinctValues'
 
+            self.gql_builder = PipelineGrapql()
+
         except Exception as error:
             raise error
 
@@ -548,28 +551,50 @@ class Pipelines(ApiRequestManager):
         raise Exception(repr(result.content))
 
     @single_org
-    def get_pipelines_v2(self, org_id=None):
+    def get_pipelines_v2(self, org_id=None, deleted=False, pipeline_type="standard"):
         """
         Retrieves the pipeline list from the given org
 
         :param org_id: Org id to be queried
         :type org_id: int or str
+        :param deleted: Deletion status fo pipeliens to be queried
+        :type deleted: bool or None
+        :param pipeline_type: Pipeline type standard or function
+        :type pipeline_type: str
         :return:
         """
-        header = self.build_header(
-            others=self.content_type_header
-        )
 
-        get_pipelines_request = self.session.get(
-            self.retrieve_pipelines_v2.format(org_id),
-            headers=header
-        )
+        if deleted is True:
+            query = self.gql_builder.get_deleted_pipelines(pipeline_type=pipeline_type)
+        elif deleted is False:
+            query = self.gql_builder.get_non_deleted_pipelines(pipeline_type=pipeline_type)
+        else:
+            query = self.gql_builder.get_pipelines_query(pipeline_type=pipeline_type)
 
-        if get_pipelines_request.status_code == 200:
-            return json.loads(get_pipelines_request.content)
+        get_pipelines_request = self.graph_ql_query(org_id=org_id, query=query)
 
+        if get_pipelines_request.status_code in range(200, 202):
+            data = json.loads(get_pipelines_request.content)
+            if "data" in data:
+                if "artifacts" in data["data"]:
+                    return data["data"]["artifacts"]
+
+            return []
         raise Exception(repr(get_pipelines_request.content))
 
+    @single_org
+    def get_pipelines_functions(self, org_id=None, deleted=False):
+        """
+        Retrieves the pipeline list from the given org
+
+        :param org_id: Org id to be queried
+        :type org_id: int or str
+        :param deleted: Deletion status fo pipeliens to be queried
+        :type deleted: bool or None
+        :return:
+        """
+        return self.get_pipelines_v2(org_id=org_id, deleted=deleted, pipeline_type="function")
+
     @single_org
     def verify_if_pipeline_exists_and_get_id(self, org_id=None, *, pipeline_name):
         """
@@ -583,15 +608,15 @@ class Pipelines(ApiRequestManager):
         """
 
         if pipeline_name is None:
-            raise Exception("New pipeline name cant be none")
+            raise Exception("Pipeline name cant be none")
 
         pipeline_list = self.get_pipelines_v2(org_id=org_id)
 
         results = {"pipeline_id": None}
 
-        for pipe in pipeline_list["pipelineSummaries"]:
+        for pipe in pipeline_list:
             if pipe["name"] == pipeline_name:
-                existing_pipeline_id = pipe["id"]
+                existing_pipeline_id = pipe["id"]["id"]
                 results.update({"pipeline_id": existing_pipeline_id})
                 break
 
@@ -609,7 +634,7 @@ class Pipelines(ApiRequestManager):
         :return:
         """
         if pipeline_name is None:
-            raise Exception("New pipeline name cant be none")
+            raise Exception("Pipeline name cant be none")
 
         return self.verify_if_pipeline_exists_and_get_id(
             org_id=org_id,
@@ -617,7 +642,7 @@ class Pipelines(ApiRequestManager):
         )["pipeline_id"] is not None
 
     @single_org
-    def update_pipeline_metadata(self, org_id=None, *, pipeline_id, name, description="", facets=None):
+    def update_pipeline_metadata(self, org_id=None, *, pipeline_id=None, name=None, description=None, facets=None):
         """
         Method to update a pipeline's metadata
         :param org_id: org id where the pipeline is stored
@@ -628,29 +653,14 @@ class Pipelines(ApiRequestManager):
         :return:
         """
 
-        headers = self.build_header(
-            others=self.content_type_header,
-            org_id=str(org_id)
+        query = self.gql_builder.mutation_query(
+            pipeline_id=str(pipeline_id),
+            new_name=name,
+            description=description,
+            facets=facets
         )
 
-        self.get_pipeline(
-            org_id=org_id,
-            pipeline_id=pipeline_id
-        )
-
-        body = {
-            "name": name,
-            "description": description,
-            "facets": [] if facets is None else facets
-        }
-
-        url = self.pipelines_url_v2.format(org_id, pipeline_id)
-
-        response = self.session.put(
-            url,
-            json=body,
-            headers=headers
-        )
+        response = self.graph_ql_query(org_id=org_id, query=query)
 
         if response.status_code in [200, 201, 202]:
             return json.loads(response.content)
